summaryrefslogtreecommitdiffstats
path: root/akregator/src/feedlistview.h
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/feedlistview.h')
-rw-r--r--akregator/src/feedlistview.h20
1 files changed, 11 insertions, 9 deletions
diff --git a/akregator/src/feedlistview.h b/akregator/src/feedlistview.h
index efa84392..1a5111f4 100644
--- a/akregator/src/feedlistview.h
+++ b/akregator/src/feedlistview.h
@@ -18,8 +18,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef AKREGATORFEEDLISTVIEW_H
#define AKREGATORFEEDLISTVIEW_H
@@ -39,8 +39,9 @@ class TagNodeList;
class NodeListView : public KListView
{
Q_OBJECT
+ TQ_OBJECT
public:
- NodeListView( TQWidget *parent = 0, const char *name = 0 );
+ NodeListView( TQWidget *tqparent = 0, const char *name = 0 );
virtual ~NodeListView();
/** sets the feed list to show. Disconnects from the old feed list, if there is any. */
@@ -91,7 +92,7 @@ public slots:
void slotItemBegin();
/** select last item in the list */
void slotItemEnd();
/** go to parent item */
void slotItemLeft();
/** go to first child */
void slotItemRight();
@@ -132,7 +133,7 @@ public: // compat with KDE-3.x assertions, remove for KDE 4
int cx, int cy, int cw, int ch );
virtual void contentsDragMoveEvent(TQDragMoveEvent* event);
virtual bool acceptDrag(TQDropEvent *event) const;
- virtual void movableDropEvent(TQListViewItem* parent, TQListViewItem* afterme);
+ virtual void movableDropEvent(TQListViewItem* tqparent, TQListViewItem* afterme);
virtual TQDragObject *dragObject();
@@ -154,10 +155,10 @@ protected slots:
/** called when a node is added to the tree. If no item for the node exists, it will be created */
virtual void slotNodeAdded(TreeNode* node);
- /** Called when a node in the tree is taken out of the tree (parent->removeChild())
+ /** Called when a node in the tree is taken out of the tree (tqparent->removeChild())
- Removes a node and its children from the tree. Note that it doesn't delete the corresponding view items (get deleted only when the node itself gets deleted) */
- virtual void slotNodeRemoved(Folder* parent, TreeNode* node);
+ Removes a node and its tqchildren from the tree. Note that it doesn't delete the corresponding view items (get deleted only when the node itself gets deleted) */
+ virtual void slotNodeRemoved(Folder* tqparent, TreeNode* node);
/** deletes the item belonging to the deleted node */
virtual void slotNodeDestroyed(TreeNode* node);
@@ -192,8 +193,9 @@ public: // compat with KDE-3.x assertions, remove for KDE 4
class TagNodeListView : public NodeListView
{
Q_OBJECT
+ TQ_OBJECT
public:
- TagNodeListView(TQWidget *parent = 0, const char *name = 0) {}
+ TagNodeListView(TQWidget *tqparent = 0, const char *name = 0) {}
virtual ~TagNodeListView() {}
private:
@@ -91,7 +92,7 @@ public slots:
/** select last item in the list */
void slotItemEnd();
- /** go to parent item */
+ /** go to tqparent item */
void slotItemLeft();
/** go to first child */